@@ -423,6 +423,9 @@ create_mail_widgets (MailCheck *mc)
 	char *fname = mail_animation_filename (mc);
 
 	mc->ebox = gtk_event_box_new();
+        gtk_widget_set_events(mc->ebox, 
+                              gtk_widget_get_events(mc->ebox) |
+                              GDK_BUTTON_PRESS_MASK);
 	gtk_widget_show (mc->ebox);
 	
 	/*
@@ -451,7 +454,6 @@ create_mail_widgets (MailCheck *mc)
 	gtk_drawing_area_size (GTK_DRAWING_AREA(mc->da),
 			       mc->size, mc->size);
 	gtk_signal_connect (GTK_OBJECT(mc->da), "expose_event", (GtkSignalFunc)icon_expose, mc);
-	gtk_widget_set_events(GTK_WIDGET(mc->da),GDK_EXPOSURE_MASK);
 	gtk_widget_show (mc->da);
 
 	/* The label */
@@ -1078,7 +1080,7 @@ applet_save_session(GtkWidget *w,
 static void
 mailcheck_about(AppletWidget *a_widget, gpointer a_data)
 {
-	GtkWidget *about = NULL;
+	static GtkWidget *about = NULL;
 	static const gchar     *authors [] =
 	{
 		"Miguel de Icaza <miguel@kernel.org>",
@@ -1087,12 +1089,21 @@ mailcheck_about(AppletWidget *a_widget, gpointer a_data)
 		"Lennart Poettering <poettering@gmx.net>",
 		NULL
 	};
+
+	if (about != NULL)
+	{
+		gdk_window_show(about->window);
+		gdk_window_raise(about->window);
+		return;
+	}
 	
 	about = gnome_about_new ( _("Mail check Applet"), "1.0",
 				  _("(c) 1998 the Free Software Foundation"),
 				  authors,
 				  _("Mail check notifies you when new mail is on your mailbox"),
 				  NULL);
+	gtk_signal_connect( GTK_OBJECT(about), "destroy",
+			    GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about );
 	gtk_widget_show(about);
 }
 
@@ -1116,6 +1127,13 @@ applet_change_pixel_size(GtkWidget * w, int size, gpointer data)
 	}
 }
 
+static void
+help_cb (AppletWidget *widget, gpointer data)
+{
+	GnomeHelpMenuEntry help_ref = { "mailcheck", "index.html"};
+	gnome_help_display (NULL, &help_ref);
+}
+
 GtkWidget *
 make_mailcheck_applet(const gchar *goad_id)
 {
@@ -1200,11 +1218,7 @@ make_mailcheck_applet(const gchar *goad_id)
 	gtk_widget_show(mailcheck);
 	applet_widget_add (APPLET_WIDGET (applet), mailcheck);
 
-        gtk_widget_set_events(GTK_WIDGET(applet), 
-                              gtk_widget_get_events(GTK_WIDGET(applet)) |
-                              GDK_BUTTON_PRESS_MASK);
-
-        gtk_signal_connect(GTK_OBJECT(mailcheck), "button_press_event",
+        gtk_signal_connect(GTK_OBJECT(mc->ebox), "button_press_event",
                            GTK_SIGNAL_FUNC(exec_clicked_cmd), mc);
 
 	gtk_signal_connect(GTK_OBJECT(applet),"save_session",
@@ -1217,13 +1231,20 @@ make_mailcheck_applet(const gchar *goad_id)
 					      _("Properties..."),
 					      mailcheck_properties,
 					      mc);
-
+	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
+					      "help",
+					      GNOME_STOCK_PIXMAP_HELP,
+					      _("Help"),
+					      help_cb,
+					      NULL);
 	applet_widget_register_stock_callback(APPLET_WIDGET(applet),
 					      "about",
 					      GNOME_STOCK_MENU_ABOUT,
 					      _("About..."),
 					      mailcheck_about,
-					      NULL);
+					      NULL);	
+
+
 	gtk_widget_show (applet);
 	return applet;
 }
