@@ -282,7 +282,10 @@ draw_task (TasklistTask *task)
 		text_height = gdk_string_height (area->style->font, "1");
 		text_width = gdk_string_width (area->style->font, tempstr);
 		gdk_draw_string (area->window,
-				 area->style->font, area->style->black_gc,
+				 area->style->font,
+				 GWMH_TASK_FOCUSED (task->gwmh_task) ?
+				 area->style->fg_gc[GTK_STATE_ACTIVE] :
+				 area->style->fg_gc[GTK_STATE_NORMAL],
 				 task->x +
 				 (Config.show_mini_icons ? 8 : 0) +
 				 ((task->width - text_width) / 2),
@@ -456,7 +459,7 @@ layout_tasklist (void)
 		}
 
 		curheight = ROW_HEIGHT;
-		if(Config.follow_panel_size)
+		if (Config.follow_panel_size)
 			curwidth = panel_size - 4;
 		else
 			curwidth = Config.vert_width - 4;
@@ -699,12 +702,20 @@ cb_properties (void)
 static void
 cb_about (void)
 {
-	GtkWidget *dialog;
+	static GtkWidget *dialog = NULL;
 
 	const char *authors[] = {
 		"Anders Carlsson (andersca@gnu.org)",
 		NULL
 	};
+
+	/* Stop the about box from being shown twice at once */
+	if (dialog != NULL)
+	{
+		gdk_window_show (dialog->window);
+		gdk_window_raise (dialog->window);
+		return;
+	}
 	
 	dialog = gnome_about_new ("Gnome Tasklist",
 				  VERSION,
@@ -712,6 +723,9 @@ cb_about (void)
 				  authors,
 				  "A tasklist for the GNOME desktop environment.\nIcons by Tuomas Kuosmanen (tigert@gimp.org).",
 				  NULL);
+	gtk_signal_connect (GTK_OBJECT(dialog), "destroy",
+			    GTK_SIGNAL_FUNC(gtk_widget_destroyed), &dialog);
+
 	gtk_widget_show (dialog);
 	gdk_window_raise (dialog->window);
 }
@@ -743,10 +757,10 @@ change_size (gboolean layout)
 	switch (applet_widget_get_panel_orient (APPLET_WIDGET (applet))) {
 	case ORIENT_UP:
 	case ORIENT_DOWN:
-		if (Config.horz_fixed)
+/*		if (Config.horz_fixed)
 			horz_width = Config.horz_width;
 		else
-			horz_width = 4;
+		horz_width = 4;*/
 		GTK_HANDLE_BOX (handle)->handle_position = GTK_POS_LEFT;
 		gtk_widget_set_usize (handle, 
 				      DRAG_HANDLE_SIZE + horz_width,
@@ -757,10 +771,10 @@ change_size (gboolean layout)
 		break;
 	case ORIENT_LEFT:
 	case ORIENT_RIGHT:
-		if (Config.vert_fixed)
+/*		if (Config.vert_fixed)
 			vert_height = Config.vert_height;
 		else
-			vert_height = 4;
+		vert_height = 4;*/
 		GTK_HANDLE_BOX (handle)->handle_position = GTK_POS_TOP;
 		gtk_widget_set_usize (handle, 
 				      (Config.follow_panel_size?
