@@ -19,6 +19,7 @@
 #include <config.h>
 #include <string.h>
 #include <stdlib.h>
+#include <glib.h>
 #include <gtk/gtk.h>
 #include <libgnome/libgnome.h>
 #include <unistd.h>
@@ -30,6 +31,7 @@ extern int errno;
 
 #include "manager.h"
 #include "session.h"
+#include "splash.h"
 
 /* The save_state gives a description of what we are doing */
 static enum {
@@ -40,7 +42,6 @@ static enum {
   SAVE_PHASE_2,
   SAVE_CANCELLED,
   STARTING_SESSION,
-  STARTING_WARNER,
   SHUTDOWN
 } save_state;
 
@@ -63,10 +64,10 @@ GSList *purge_retain_list = NULL;
 GSList *live_list = NULL;
 
 /* Timeout for clients that are slow to respond to SmSaveYourselfRequest */
-gint warn_timeout_id = -1;
+static gint warn_timeout_id = -1;
 
 /* Used to monitor programs that claim to be interacting. */
-gboolean interact_ping_replied = TRUE;
+static gboolean interact_ping_replied = TRUE;
 
 /* A queued save yourself request */
 typedef struct _SaveRequest
@@ -122,7 +123,7 @@ gchar   *events[]       = { GsmInactive, GsmInactive,
 			    GsmConnected, NULL };
 
 /* Index used to identify clients uniquely over the gsm protocol extensions. */
-guint handle = 0;
+static guint handle = 0;
 
 static gint compare_interact_request (gconstpointer a, gconstpointer b);
 typedef void message_func (SmsConn connection);
@@ -296,6 +297,8 @@ run_command (Client* client, const gchar* command)
 	 reasons.  */
       free_vector (envc, envv);
 
+      update_splash (argv[0], (gfloat)client->priority);
+
       restart_info = NULL;
       find_string_property (client, GsmRestartService, &restart_info);
       pid = remote_start (restart_info, argc, argv, dir, envpc, envp);
@@ -359,9 +362,9 @@ process_load_request (GSList *client_list)
     {
       Client *client = (Client*)list->data;
       gboolean bad_match = FALSE;
-	
-      list = list->next;
 
+      list = list->next;
+	
       if (client->match_rule == MATCH_PROP)
 	{
 	  SmProp *prop = find_property_by_name (client, SmRestartCommand);
@@ -529,8 +532,9 @@ remove_client (Client* client)
   for (list = save_request_list; list;)
     {
       SaveRequest *request = (SaveRequest*)list->data;
-      
+
       list = list->next;
+
       if (request->client == client) {
 	g_free(request);
 	REMOVE (save_request_list, request);
@@ -702,7 +706,8 @@ register_client (SmsConn connection, SmPointer data, char *previous_id)
 	  /* The typecast there is for 64-bit machines */
 	  client->id = malloc (43);
 	  sprintf (client->id, "1%s%.13ld%.10d%.4d", address,
-		   (long) time(NULL), getpid (), sequence++);
+		   (long) time(NULL), getpid (), sequence);
+	  sequence++;
 	  
 	  sequence %= 10000;
 	}
@@ -850,13 +855,15 @@ no_response_warning (gpointer data)
 	for (list = save_yourself_p2_list; list; )
 	  {
 	    Client* client = (Client *) list->data;
+
 	    list = list->next;
+
 	    client_reasons (client, TRUE, 3, reasons);
 	  }
 	/* fall through */
 	
       case SAVE_PHASE_1:
-	for (list = save_yourself_list; list; )
+	for (list = save_yourself_list; list;)
 	  {
 	    Client* client = (Client *) list->data;
 	    list = list->next;
@@ -865,7 +872,7 @@ no_response_warning (gpointer data)
 	break;
 	
       case SHUTDOWN:
-	for (list = live_list; list; )
+	for (list = live_list; list;)
 	  {
 	    Client* client = (Client *) list->data;
 	    list = list->next;
@@ -945,11 +952,11 @@ process_save_request (Client* client, int save_type, gboolean shutdown,
 	{	
 	  while (live_list) 
 	    {
-	      Client *client = (Client *) live_list->data;
-	      client_event (client->handle, GsmSave);
-	      REMOVE (live_list, client);
-	      APPEND (save_yourself_list, client);
-	      SmsSaveYourself (client->connection, save_type, shutting_down,
+	      Client *tmp_client = (Client *) live_list->data;
+	      client_event (tmp_client->handle, GsmSave);
+	      REMOVE (live_list, tmp_client);
+	      APPEND (save_yourself_list, tmp_client);
+	      SmsSaveYourself (tmp_client->connection, save_type, shutting_down,
 			       interact_style, fast);
 	    }
 	}
@@ -1061,6 +1068,7 @@ update_save_state ()
 	    return;
 	}
       save_state = MANAGER_IDLE;
+      stop_splash ();
      }    
 
   if (save_state == SAVE_PHASE_1)
@@ -1330,8 +1338,8 @@ client_clean_up (Client* client)
   for (list = save_request_list; list;)
     {
       SaveRequest *request = (SaveRequest*)list->data;
-      
       list = list->next;
+      
       if (request->client == client) {
 	g_free(request);
 	REMOVE (save_request_list, request);
