@@ -384,9 +384,6 @@ ebox_size_allocate(GtkWidget *applet, GtkAllocation *alloc, Extern *ext)
 static void
 socket_size_allocate(GtkWidget *applet, GtkAllocation *alloc)
 {
-	GtkWidget *plug_widget;
-	GtkSocket *socket = GTK_SOCKET(applet);
-
 	/* perhaps an already unnecessary hack to avoid some missed
 	   reallocations */
 	if (applet->requisition.width > 0 && applet->requisition.height > 0 &&
@@ -394,56 +391,8 @@ socket_size_allocate(GtkWidget *applet, GtkAllocation *alloc)
 	     applet->allocation.height > applet->requisition.height))
 		gtk_widget_queue_resize(applet->parent);
 
-#if 0
-
-	if (!socket->same_app ||
-	    !socket->plug_window)
-		return;
-    
-	gdk_window_get_user_data (socket->plug_window,
-				  (gpointer *)&plug_widget);
-	if (plug_widget) {
-		GtkAllocation child_allocation;
-		child_allocation.x = child_allocation.y = 0;
-		child_allocation.width = alloc->width;
-		child_allocation.height = alloc->height;
-		gtk_widget_size_allocate (plug_widget, &child_allocation);
-	}
-	gdk_window_move_resize (socket->plug_window,
-				0, 0, alloc->width, alloc->height);
-	if (socket->need_map) {
-		gdk_window_show (socket->plug_window);
-		socket->need_map = FALSE;
-	}
-	gdk_flush ();
-#endif
 }
 
-#if 0
-static void
-socket_size_request(GtkSocket *socket, GtkRequisition *req)
-{
-	GtkWidget *plug_widget;
-
-	if (!socket->same_app ||
-	    !socket->plug_window)
-		return;
-
-	gdk_window_get_user_data (socket->plug_window,
-				  (gpointer *)&plug_widget);
-	if (plug_widget) {
-		GtkRequisition child_requisition;
-		gtk_widget_size_request (plug_widget, &child_requisition);
-
-		socket->request_width = child_requisition.width;
-		socket->request_height = child_requisition.height;
-	}
-
-	req->width = MAX (socket->request_width, 1);
-	req->height = MAX (socket->request_height, 1);
-}
-#endif
-
 /*note that type should be APPLET_EXTERN_RESERVED or APPLET_EXTERN_PENDING
   only*/
 static CORBA_unsigned_long
@@ -468,9 +417,6 @@ reserve_applet_spot (Extern *ext, PanelWidget *panel, int pos,
 		return 0;
 	}
 
-	/*gtk_signal_connect_after(GTK_OBJECT(socket),"size_request",
-				 GTK_SIGNAL_FUNC(socket_size_request),
-				 NULL);*/
 	gtk_signal_connect_after(GTK_OBJECT(socket),"size_allocate",
 				 GTK_SIGNAL_FUNC(socket_size_allocate),
 				 NULL);
@@ -1050,14 +996,16 @@ s_panelspot_show_menu(PortableServer_Servant servant,
 	g_assert(ext != NULL);
 	g_assert(ext->info != NULL);
 
-	if (!ext->info->menu)
-		create_applet_menu(ext->info);
-
 	panel = get_panel_parent(ext->info->widget);
 
-	BASEP_WIDGET(panel)->autohide_inhibit = TRUE;
-	basep_widget_queue_autohide(BASEP_WIDGET(panel));
-	
+	if (!ext->info->menu)
+		create_applet_menu(ext->info, IS_BASEP_WIDGET (panel));
+
+	if (IS_BASEP_WIDGET (panel)) {
+		BASEP_WIDGET(panel)->autohide_inhibit = TRUE;
+		basep_widget_queue_autohide(BASEP_WIDGET(panel));
+	}
+
 	ext->info->menu_age = 0;
 	gtk_menu_popup(GTK_MENU(ext->info->menu), NULL, NULL,
 		       global_config.off_panel_popups?applet_menu_position:NULL,
