@@ -39,7 +39,8 @@ typedef enum {
 	DRAWER_PANEL,
 	ALIGNED_PANEL,
 	SLIDING_PANEL,
-	FLOATING_PANEL
+	FLOATING_PANEL,
+	FOOBAR_PANEL
 } PanelType;
 
 #endif
